@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Pod::WSDL::AUTOLOAD;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 our @ISA = qw/Pod::WSDL::AUTOLOAD/;
 
 our %FORBIDDEN_METHODS = (
@@ -27,7 +27,7 @@ sub new {
 	$type ||= ''; # avoids warnings, dies soon
 	
 	$type =~ /([\$\@])(.+)/;
-	die "Type '$type' must have structure ($|@)<typename>, e.g. '\$boolean' or '\@string', not '$type' died" unless $1 and $2;
+	die "Type '$type' must have structure (\$|@)<typename>, e.g. '\$boolean' or '\@string', not '$type' died" unless $1 and $2;
 	
 	bless {
 		_name      => $name,
@@ -82,7 +82,7 @@ see Pod::WSDL
  
 =head1 AUTHOR
 
-Tarek Ahmed, E<lt>luke.lubbock -the character every email address contains- gmx.netE<gt>
+Tarek Ahmed, E<lt>bloerch -the character every email address contains- oelbsk.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
